@@ -615,11 +615,43 @@ print "\n\n\n\n\n\n\nSTDERR=$stderr\n\n\n\n\n\n\n";
    ($stdout,$stderr)=$handle->cmd($sudo.
       'chmod -v 777 fullauto_clickable_image.png','__display__');
    ($stdout,$stderr)=$handle->cwd('~');
-   my $sd='/var/www/gnusocial/theme/neo-gnu';
+   my $sd='/var/www/gnusocial/theme/base';
    ($stdout,$stderr)=$handle->cmd($sudo.
       "mv -vf fullauto_clickable_image.png $sd",'__display__');
    ($stdout,$stderr)=$local->cmd($sudo.
       "rm -rvf fullauto_clickable_image.png",'__display__');
+   $ad="        'fullauto' =>%NL%".
+      "        array('url' => 'http://www.fullauto.com',%NL%".
+      "              'title' => 'FullAuto - Automates EVERYTHING',%NL%".
+      "              'image' => %NL%".
+      "\$_path.'/theme/base/fullauto_clickable_image.png'),%NL%";
+   ($stdout,$stderr)=$handle->cmd("${sudo}sed -i ".
+      "\'/cc_by_3.0_80x15/a$ad\' /var/www/gnusocial/lib/default.php");
+   ($stdout,$stderr)=$handle->cmd(
+       "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" ".
+       "/var/www/gnusocial/lib/default.php");
+   $handle->cmd_raw(
+       "${sudo}sed -i 's#\\(^'fullauto' =[>]$\\\)#        \\1#' ".
+       '/var/www/gnusocial/lib/default.php');
+   $ad='    function showFullAuto()%NL%'.
+      '    {%NL%'.
+      "        \$this->elementStart('div', array('id' => 'fullauto'));%NL%".
+      "        \$image    = common_config('fullauto', 'image');%NL%".
+      "        \$this->element('img', array('id' => 'fullauto',%NL%".
+      "                                    'src' => Theme::path('fullauto_clickable_image.png'),%NL%".
+      "                                    'alt' => common_config('fullauto', 'title'),%NL%".
+      "                                    'width' => '83',%NL%".
+      "                                    'height' => '40'));%NL%".
+      "        \$this->elementEnd('div');%NL%".
+      "    }%NL%";
+   ($stdout,$stderr)=$handle->cmd("${sudo}sed -i ".
+      "\'/function showFooter/i$ad\' /var/www/gnusocial/lib/action.php");
+   ($stdout,$stderr)=$handle->cmd(
+       "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" ".
+       "/var/www/gnusocial/lib/action.php");
+   $handle->cmd_raw(
+       "${sudo}sed -i 's#\\(^function showFullAuto[(][)]$\\\)#    \\1#' ".
+       '/var/www/gnusocial/lib/action.php');
    #
    # echo-ing/streaming files over ssh can be tricky. Use echo -e
    #          and replace these characters with thier HEX
